CytobandData ClassA class to represent genome-wide data measured or summarized at cytoband-level resoluton.
CytobandData(data, info, genome = NULL)
# S4 method for CytobandData
summary(object, ...)The CytobandData conxtructor returns an object of the
CytobandData class. The summary method returns a table,
which is the usual return value when the summary method is applied to a
data frame (in this case, the DATA slot).
A data frame that must contain at least one
numeric column and may contain the five cytoband location
columns. If the latter are missing, they must be supplied by the
genome argument.
A data frame with Label and
Description columns. If missing, it will be created from the
column names in the data argument.
A data frame containing cytoband
locations. Often, simply uses the cytobandLocations
object describing build 38 of the human genome.
An object of the CytobandData class.
Additional arguments to the summary method; ignored.
DATA:A data frame containg five columns (Chromosome, loc.start, loc.end, Band, and Stain) defining chromosomal locations of cytobands, along with one or more columns of numerical data at cytoband resolution.
INFO:A data frame with two columns (Label and
Description) that describes the columns of the DATA slot.
signature(object = "RCytoGPS")
Returns a summary of the DATA slot.
Kevin R. Coombes krc@silicovore.com, Dwayne G. Tally dtally110@hotmail.com
Conventional karyotyping describes chromosomal abnormalities (in a
standardized text-based nomenclature) that are visible through a
microsope. Karyotyping relies on a technique known as Giemsa staining,
which creates a banding pattern along the chromosome of different
shades of gray. The Loss-Gain-Fusion (LGF) model implemented at the
http://cytogps.org web site converts text-based karyotypes into
binary vectors, stored in JSON files. Our readLGF
function parses the JSON files to create R data structures, including
cytoband-resolution summaries of the frequencies of
abnormalities. These summaries can be used to create
CytobandData objects, which can be visualized using the
barplot and image methods.
Abrams ZB, Tally DG, Coombes KR. RCytoGPS: An R Package for Analyzing and Visualizing Cytogenetic Data. In preparation.
Abrams ZB, Tally DG, Zhang L, Coombes CE, Payne PRO, Abruzzo LV, Coombes KR. Pattern recognition in lymphoid malignancies using CytoGPS and Mercator. Under review.
jsonDir <- system.file("Examples/JSONfiles", package = "RCytoGPS")
temp <- readLGF(folder = jsonDir)
cytoData <- data.frame(temp[["CL"]],temp[["frequency"]])
bandData <- CytobandData(cytoData)
class(bandData)
summary(bandData)
Run the code above in your browser using DataLab