- x
An object of the CytobandData-class, which
combines numerical data at cytoband resolution with information on
the chromosomal locations of the cytobands.
- chr
The specific chromosome you want to view, typically in
c(1:22, "X", "Y"). if you want to see all the chromosomes
at once then you can set chr = "all".
- what
A vector or list containing the names of the numerical
column(s) that you want to display from the data frame. The
barplot method only shows a single data column at a time. The
plots resulting from the image method change depending on
whether you supply a vector or a list, as well as on the length. For
more details, see the vignettes, espefcialy the image gallery.
- pal
a charcter vector containing the colors you want to use
for different data shown in the plot.
- horiz
A logical value determining whether images present the
chromosome idiograms horizontally or vertically.
- nrows
Only used when chr = "all" to determine the number
of rows to use to display different chromosomes. Must be an integer
between 1 and 4.
- labels
Only use when what is a character vector (not a
list) and chr is mot equal to "all". Used to label
differnt columns of displayed data.
- axes
Logical value; should axes be displayed?
- legend
Logicla value; should a legend be added to the plot.
- sigcolumn
The three parameters sigcolumn,
sigcut, and alpha are used as a set. The first names a
numerical column in the data set used to define "significance". The
second is a vector of cutoffs that mark levels of significance. The
latter is a number between 0 and 255 denoting the transparency level
assigned to the color for each significance level.
- sigcut
See sigcolumn.
- alpha
See sigcolumn.
- clip
A logical value; should te length of the chromosome fill
the device (if TRUE) or be plotted relative to the length of Chromosome
1 (if FALSE). Currently only used when plotting two values, one on
either side of a single chromosome.
- debug
Logical value; should the method print out debugging
information. Probably best to ignore.
- height
An object of the CytobandData-class, which
combines numerical data at cytoband resolution with information on
the chromosomal locations of the cytobands.
- col
a character vector containing the colors you want to use
for different data shown in the plot.
- altcol
Determines the color used, lternating with white, in the
x-axis plot of all chromosomes.
- ylab
Label for the y-axis in a barplot.
- hline
Numeric vector of heights at which toadd a horizontal
line.
- xform
Function to transform the data before plotting. Defauly
is the identity map, which does nothing.
- ...
Ignored.