Learn R Programming

RCytoGPS (version 1.2.10)

cytoband-data: Example Cytoband Data

Description

This data set contains the genomic locations of cytobands along with loss-gain-fusion percentages for three group of samples.

Usage

data(cytoData)

Arguments

Format

A data matrix (cytobandLocations) containing 868 rows and 14 columns. Each row contains one of the cytobands defined in the 2016 update to ISCN nomenclature. The rownames are the standard cytoband names; for example, 1p36.33. The first five columns are the same as in the cytobandLocations data set. The remaining nine columns form three sets of three, recording the percentage of Loss, Gain, and Fusion events in three sets of samples, labeled "A", "B", and "C".

Author

Kevin R. Coombes krc@silicovore.com, Dwayne G. Tally dtally110@hotmail.com

References

J. McGowan-Jordan, A. Simons, M. Schmid (editors). ISCN 2016: An International System for Human Cytogenomic Nomenclature. Karger Publishing, Basel, 2016.

Mitelman, F., B. Johansson, and F. Mertens, Catalog of chromosome aberrations in cancer. Vol. 1. 1991: Wiley-Liss New York.