This data set contains the genomic locations of cytobands based on both the latest build of the human genome (GRch38) and the latest update to the International Standard for human Cytogenomic Nomenclature (ISCN). Note that the CRch38 locations are unchanged from build GRch37 (hg19).
data(cytobandLocations)A data matrix (cytobandLocations) containing 868 rows and
5 columns. Each row contains one of the cytobands defined in the 2016
update to ISCN nomenclature. The rownames are the standard cytoband
names; for example, 1p36.33. The columns are
The name of the human chromosome, stored as
chr#.
loc.startThe starting base position of the band.
loc.endThe ending base position of the band.
BandThe band name without the chromosome; for
example, p36.33.
StainA factor containing the name of the Giemsa-stain color of the band in a karyotype image.
Also, a vector (idiocolors) of length eight that translates the
Giemsa stain names into appropriate colors.
Kevin R. Coombes krc@silicovore.com, Dwayne G. Tally dtally110@hotmail.com
J. McGowan-Jordan, A. Simons, M. Schmid (editors). ISCN 2016: An International System for Human Cytogenomic Nomenclature. Karger Publishing, Basel, 2016.